package com.zehong.system.service.impl.project;

import com.zehong.common.utils.DateUtils;
import com.zehong.common.utils.SecurityUtils;
import com.zehong.system.domain.project.TProductProject;
import com.zehong.system.mapper.project.TProductProjectMapper;
import com.zehong.system.service.project.ITProductProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 项目资料Service业务层处理
 * 
 * @author zehong
 * @date 2024-08-19
 */
@Service
public class TProductProjectServiceImpl implements ITProductProjectService 
{
    @Autowired
    private TProductProjectMapper tProductProjectMapper;

    /**
     * 查询项目资料
     * 
     * @param id 项目资料ID
     * @return 项目资料
     */
    @Override
    public TProductProject selectTProductProjectById(Long id)
    {
        return tProductProjectMapper.selectTProductProjectById(id);
    }

    /**
     * 查询项目资料列表
     * 
     * @param tProductProject 项目资料
     * @return 项目资料
     */
    @Override
    public List<TProductProject> selectTProductProjectList(TProductProject tProductProject)
    {
        return tProductProjectMapper.selectTProductProjectList(tProductProject);
    }

    /**
     * 新增项目资料
     * 
     * @param tProductProject 项目资料
     * @return 结果
     */
    @Override
    public int insertTProductProject(TProductProject tProductProject)
    {
        tProductProject.setCreateTime(DateUtils.getNowDate());
        tProductProject.setCreateId(SecurityUtils.getLoginUser().getUser().getUserId());
        return tProductProjectMapper.insertTProductProject(tProductProject);
    }

    /**
     * 修改项目资料
     * 
     * @param tProductProject 项目资料
     * @return 结果
     */
    @Override
    public int updateTProductProject(TProductProject tProductProject)
    {
        return tProductProjectMapper.updateTProductProject(tProductProject);
    }

    /**
     * 批量删除项目资料
     * 
     * @param ids 需要删除的项目资料ID
     * @return 结果
     */
    @Override
    public int deleteTProductProjectByIds(Long[] ids)
    {
        return tProductProjectMapper.deleteTProductProjectByIds(ids);
    }

    /**
     * 删除项目资料信息
     * 
     * @param id 项目资料ID
     * @return 结果
     */
    @Override
    public int deleteTProductProjectById(Long id)
    {
        return tProductProjectMapper.deleteTProductProjectById(id);
    }
}
