package com.zehong.system.service.impl.track;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import com.zehong.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.track.TProductMarkDetailMapper;
import com.zehong.system.domain.track.TProductMarkDetail;
import com.zehong.system.service.track.ITProductMarkDetailService;

/**
 * 装配详情Service业务层处理
 * 
 * @author zehong
 * @date 2024-08-24
 */
@Service
public class TProductMarkDetailServiceImpl implements ITProductMarkDetailService 
{
    @Autowired
    private TProductMarkDetailMapper tProductMarkDetailMapper;

    /**
     * 查询装配详情
     * 
     * @param id 装配详情ID
     * @return 装配详情
     */
    @Override
    public TProductMarkDetail selectTProductMarkDetailById(Long id)
    {
        return tProductMarkDetailMapper.selectTProductMarkDetailById(id);
    }

    /**
     * 查询装配详情列表
     * 
     * @param tProductMarkDetail 装配详情
     * @return 装配详情
     */
    @Override
    public List<TProductMarkDetail> selectTProductMarkDetailList(TProductMarkDetail tProductMarkDetail)
    {
        return tProductMarkDetailMapper.selectTProductMarkDetailList(tProductMarkDetail);
    }

    /**
     * 新增装配详情
     * 
     * @param tProductMarkDetail 装配详情
     * @return 结果
     */
    @Override
    public int insertTProductMarkDetail(TProductMarkDetail tProductMarkDetail)
    {
        tProductMarkDetail.setCreateTime(DateUtils.getNowDate());
        tProductMarkDetail.setCreateId(SecurityUtils.getLoginUser().getUser().getUserId());
        return tProductMarkDetailMapper.insertTProductMarkDetail(tProductMarkDetail);
    }

    /**
     * 修改装配详情
     * 
     * @param tProductMarkDetail 装配详情
     * @return 结果
     */
    @Override
    public int updateTProductMarkDetail(TProductMarkDetail tProductMarkDetail)
    {
        return tProductMarkDetailMapper.updateTProductMarkDetail(tProductMarkDetail);
    }

    /**
     * 批量删除装配详情
     * 
     * @param ids 需要删除的装配详情ID
     * @return 结果
     */
    @Override
    public int deleteTProductMarkDetailByIds(Long[] ids)
    {
        return tProductMarkDetailMapper.deleteTProductMarkDetailByIds(ids);
    }

    /**
     * 删除装配详情信息
     * 
     * @param id 装配详情ID
     * @return 结果
     */
    @Override
    public int deleteTProductMarkDetailById(Long id)
    {
        return tProductMarkDetailMapper.deleteTProductMarkDetailById(id);
    }
}
